@@ -168,6 +168,126 @@ public interface A3CanvasInterface {
      */
     public void addCameraLocImmediately(Vector3d loc);
 
+    /**
+     * カメラを前方に指定距離だけ移動します。
+     */
+    public void moveCameraForward(double l);
+
+    /**
+     * カメラを前方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraForwardImmediately(double l);
+
+    /**
+     * カメラを後方に指定距離だけ移動します。
+     */
+    public void moveCameraBackward(double l);
+
+    /**
+     * カメラを後方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraBackwardImmediately(double l);
+
+    /**
+     * カメラを右方向に指定距離だけ移動します。
+     */
+    public void moveCameraRight(double l);
+
+    /**
+     * カメラを右方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraRightImmediately(double l);
+
+    /**
+     * カメラを左方向に指定距離だけ移動します。
+     */
+    public void moveCameraLeft(double l);
+
+    /**
+     * カメラを左方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraLeftImmediately(double l);
+
+    /**
+     * カメラを上方向に指定距離だけ移動します。
+     */
+    public void moveCameraUp(double l);
+
+    /**
+     * カメラを上方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraUpImmediately(double l);
+
+    /**
+     * カメラを下方向に指定距離だけ移動します。
+     */
+    public void moveCameraDown(double l);
+
+    /**
+     * カメラを下方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraDownImmediately(double l);
+
+    /**
+     * シーンを指定して、カメラを前方に指定距離だけ移動します。
+     */
+    public void moveCameraForward(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを前方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraForwardImmediately(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを後方に指定距離だけ移動します。
+     */
+    public void moveCameraBackward(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを後方に指定距離だけ即時に移動します。
+     */
+    public void moveCameraBackwardImmediately(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを右方向に指定距離だけ移動します。
+     */
+    public void moveCameraRight(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを右方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraRightImmediately(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを左方向に指定距離だけ移動します。
+     */
+    public void moveCameraLeft(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを左方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraLeftImmediately(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを上方向に指定距離だけ移動します。
+     */
+    public void moveCameraUp(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを上方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraUpImmediately(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを下方向に指定距離だけ移動します。
+     */
+    public void moveCameraDown(double l,int scene);
+
+    /**
+     * シーンを指定して、カメラを下方向に指定距離だけ即時に移動します。
+     */
+    public void moveCameraDownImmediately(double l,int scene);
+
     /**
      * カメラの現在位置を返します。
      */
@@ -466,6 +586,16 @@ public interface A3CanvasInterface {
          * 用いてZ軸が上になる座標系に設定している場合には正常に機能しないので、ChaseControllerを
          * 用いる方法を検討して下さい。 */
         CHASE,
+        /** FPS(First Person Shooting)で良くつかわれるようなナビゲーションです。
+         * a,dで左右，w,sで前後に動き，キーボードの方向キーで視点を変更します．
+         * 視点がどちらを向いていても移動で高さが変らないようにしています．
+         */
+        FPS,
+        /** FPS(First Person Shooting)で良くつかわれるようなナビゲーションですが，
+         * 視点の方向によって地面をはなれる方向にも移動できます。
+         * a,dで左右，w,sで前後に動き，キーボードの方向キーで視点を変更します．
+         */
+        FPS_FLY,
         /** ユーザ定義のナビゲーションモードです。 */
         USER
     }
