@@ -904,6 +904,108 @@ public abstract class A3Object {
         return behavior.getTargetScaleV();
     }
 
+    /**
+     * 正面方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveForward(double l) {
+        behavior.moveForward(l);
+    }
+
+    /**
+     * 正面方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveForwardImmediately(double l) {
+        behavior.moveForwardImmediately(l);
+    }
+
+    /**
+     * 後ろ方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveBackward(double l) {
+        behavior.moveBackward(l);
+    }
+
+    /**
+     * 後ろ方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveBackwardImmediately(double l) {
+        behavior.moveBackwardImmediately(l);
+    }
+
+    /**
+     * 右方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveRight(double l) {
+        behavior.moveRight(l);
+    }
+
+    /**
+     * 右方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveRightImmediately(double l) {
+        behavior.moveRightImmediately(l);
+    }
+
+    /**
+     * 左方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveLeft(double l) {
+        behavior.moveLeft(l);
+    }
+
+    /**
+     * 左方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveLeftImmediately(double l) {
+        behavior.moveLeftImmediately(l);
+    }
+
+    /**
+     * 上方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveUp(double l) {
+        behavior.moveUp(l);
+    }
+
+    /**
+     * 上方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveUpImmediately(double l) {
+        behavior.moveUpImmediately(l);
+    }
+
+    /**
+     * 下方向にlだけに移動します．
+     * behaviorが有効であれば、補完機能が働き変更はなめらかに
+     * 反映されます。behaviorが無効であれば変更は即座に反映されます。
+     */
+    public final void moveDown(double l) {
+        behavior.moveDown(l);
+    }
+
+    /**
+     * 下方向にlだけに移動します．
+     * behaviorが有効であってもなくても、変更が即座に反映されます。
+     */
+    public final void moveDownImmediately(double l) {
+        behavior.moveDownImmediately(l);
+    }
+
     /**
      * このオブジェクトのローカルな座標系のX軸がグローバルな
      * 仮想空間の座標系ではどちらの方向になるのかを返します。
