@@ -251,6 +251,126 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         subCamBehavior.addCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        subCamBehavior.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        subCamBehavior.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        subCamBehavior.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        subCamBehavior.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        subCamBehavior.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        subCamBehavior.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        subCamBehavior.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        subCamBehavior.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        subCamBehavior.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        subCamBehavior.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        subCamBehavior.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        subCamBehavior.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        // TODO Version3系列ではこのメソッドが削除できるようにすべし。
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return subCamBehavior.getCameraLoc();
