@@ -379,6 +379,174 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         scene.setCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        scene.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        scene.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        scene.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        scene.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        scene.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        scene.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        scene.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        scene.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        scene.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        scene.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        scene.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        scene.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraForward(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraForwardImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraBackward(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraBackwardImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraRight(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraRightImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraLeft(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraLeftImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraUp(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraUpImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraDown(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        Scene s = scenes.get(scene);
+        if (s!=null)
+            s.moveCameraDownImmediately(l);
+        else
+            throw new IllegalArgumentException();
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return scene.getCameraLoc();
@@ -386,7 +554,7 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
 
     @Override
     public Vector3d getCameraTargetLoc() {
-        return scene.getCameraLoc();
+        return scene.getCameraTargetLoc();
     }
 
     @Override
