@@ -27,31 +27,37 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
      */
     public A3Widget(int w,int h) {
         super(initHack());
-        setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
-        setBounds(0,0,w,h);
+        final int ww = w;
+        final int hh = h;
+        try {
+            EventQueue.invokeAndWait(new Runnable() {
+                public void run() {
 
-        tCanvas = new TransCanvas3D(true);
-        tCanvas.canvasIF = this;
-        tCanvas.setResizeMode(TransCanvas3D.RESIZE_IMMEDIATELY);
-        this.add("Center",tCanvas);
-        Dimension dim = new Dimension(w,h);
-        tCanvas.setPreferredSize(dim);
-        tCanvas.setSize(dim);
+                    setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
+                    setBounds(0,0,ww,hh);
 
-        universe = new A3VirtualUniverse(this);
+                    tCanvas = new TransCanvas3D(true);
+                    tCanvas.canvasIF = A3Widget.this;
+                    tCanvas.setResizeMode(TransCanvas3D.RESIZE_IMMEDIATELY);
+                    A3Widget.this.add("Center",tCanvas);
+                    Dimension dim = new Dimension(ww,hh);
+                    tCanvas.setPreferredSize(dim);
+                    tCanvas.setSize(dim);
 
-        setDepthBufferFreezeTransparent(false);
+                    universe = new A3VirtualUniverse(A3Widget.this);
 
-        this.setUndecorated(true);
-        AWTUtilitiesWrapper.setWindowOpaque(this, false);
-        this.setVisible(true);
+                    setDepthBufferFreezeTransparent(false);
 
-        EventQueue.invokeLater(new Runnable() {
-            public void run() {
-                System.out.println("invokeLater");
-                tCanvas.requestFocusInWindow();
-            }
-        });
+                    A3Widget.this.setUndecorated(true);
+                    AWTUtilitiesWrapper.setWindowOpaque(A3Widget.this, false);
+                    A3Widget.this.setVisible(true);
+
+                    tCanvas.requestFocusInWindow();
+                }
+            });
+        } catch (Exception e) {
+            e.printStackTrace();
+        }
     }
     static GraphicsConfiguration initHack() {
         if (!AWTUtilitiesWrapper.isTranslucencySupported(AWTUtilitiesWrapper.PERPIXEL_TRANSLUCENT)) {
@@ -221,6 +227,126 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
         universe.addCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        universe.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        universe.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        universe.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        universe.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        universe.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        universe.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        universe.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        universe.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        universe.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        universe.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        universe.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        universe.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        universe.moveCameraForward(l,scene);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        universe.moveCameraForwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        universe.moveCameraBackward(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        universe.moveCameraBackwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        universe.moveCameraRight(l,scene);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        universe.moveCameraRightImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        universe.moveCameraLeft(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        universe.moveCameraLeftImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        universe.moveCameraUp(l,scene);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        universe.moveCameraUpImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        universe.moveCameraDown(l,scene);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        universe.moveCameraDownImmediately(l,scene);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return universe.getCameraLoc();
