@@ -203,6 +203,126 @@ public class A3Window extends JFrame implements A3CanvasInterface {
         canvas.addCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        canvas.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        canvas.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        canvas.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        canvas.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        canvas.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        canvas.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        canvas.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        canvas.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        canvas.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        canvas.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        canvas.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        canvas.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        canvas.moveCameraForward(l,scene);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        canvas.moveCameraForwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        canvas.moveCameraBackward(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        canvas.moveCameraBackwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        canvas.moveCameraRight(l,scene);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        canvas.moveCameraRightImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        canvas.moveCameraLeft(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        canvas.moveCameraLeftImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        canvas.moveCameraUp(l,scene);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        canvas.moveCameraUpImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        canvas.moveCameraDown(l,scene);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        canvas.moveCameraDownImmediately(l,scene);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return canvas.getCameraLoc();
