@@ -235,6 +235,126 @@ public class JA3Canvas2 extends TransCanvas3D implements A3CanvasInterface {
         universe.addCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        universe.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        universe.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        universe.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        universe.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        universe.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        universe.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        universe.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        universe.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        universe.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        universe.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        universe.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        universe.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        universe.moveCameraForward(l,scene);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        universe.moveCameraForwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        universe.moveCameraBackward(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        universe.moveCameraBackwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        universe.moveCameraRight(l,scene);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        universe.moveCameraRightImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        universe.moveCameraLeft(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        universe.moveCameraLeftImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        universe.moveCameraUp(l,scene);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        universe.moveCameraUpImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        universe.moveCameraDown(l,scene);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        universe.moveCameraDownImmediately(l,scene);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return universe.getCameraLoc();
