@@ -29,22 +29,27 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
      * (w,h)の大きさのA3Windowを生成します。
      */
     public JA3Window(int w,int h) {
-        addWindowListener(new WindowAdapter() {
-            public void windowClosing(WindowEvent we) {
-                dispose();
-                System.exit(0);
-            }
-        });
-        canvas = JA3Canvas.createJA3Canvas(w,h);
-        getContentPane().add(canvas);
-        pack();
-        setVisible(true);
-        EventQueue.invokeLater(new Runnable() {
-            public void run() {
-                System.out.println("invokeLater");
-                canvas.requestFocusInWindow();
-            }
-        });
+        final int ww = w;
+        final int hh = h;
+        try {
+            EventQueue.invokeAndWait(new Runnable() {
+                public void run() {
+                    addWindowListener(new WindowAdapter() {
+                        public void windowClosing(WindowEvent we) {
+                            dispose();
+                            System.exit(0);
+                        }
+                    });
+                    canvas = JA3Canvas.createJA3Canvas(ww,hh);
+                    getContentPane().add(canvas);
+                    pack();
+                    setVisible(true);
+                    canvas.requestFocusInWindow();
+                }
+            });
+        } catch (Exception e) {
+            e.printStackTrace();
+        }
     }
 
     /**
@@ -196,6 +201,126 @@ public class JA3Window extends JFrame implements A3CanvasInterface {
         canvas.addCameraLocImmediately(loc);
     }
 
+    @Override
+    public void moveCameraForward(double l) {
+        canvas.moveCameraForward(l);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l) {
+        canvas.moveCameraForwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraBackward(double l) {
+        canvas.moveCameraBackward(l);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l) {
+        canvas.moveCameraBackwardImmediately(l);
+    }
+
+    @Override
+    public void moveCameraRight(double l) {
+        canvas.moveCameraRight(l);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l) {
+        canvas.moveCameraRightImmediately(l);
+    }
+
+    @Override
+    public void moveCameraLeft(double l) {
+        canvas.moveCameraLeft(l);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l) {
+        canvas.moveCameraLeftImmediately(l);
+    }
+
+    @Override
+    public void moveCameraUp(double l) {
+        canvas.moveCameraUp(l);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l) {
+        canvas.moveCameraUpImmediately(l);
+    }
+
+    @Override
+    public void moveCameraDown(double l) {
+        canvas.moveCameraDown(l);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l) {
+        canvas.moveCameraDownImmediately(l);
+    }
+
+    @Override
+    public void moveCameraForward(double l,int scene) {
+        canvas.moveCameraForward(l,scene);
+    }
+
+    @Override
+    public void moveCameraForwardImmediately(double l,int scene) {
+        canvas.moveCameraForwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackward(double l,int scene) {
+        canvas.moveCameraBackward(l,scene);
+    }
+
+    @Override
+    public void moveCameraBackwardImmediately(double l,int scene) {
+        canvas.moveCameraBackwardImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraRight(double l,int scene) {
+        canvas.moveCameraRight(l,scene);
+    }
+
+    @Override
+    public void moveCameraRightImmediately(double l,int scene) {
+        canvas.moveCameraRightImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeft(double l,int scene) {
+        canvas.moveCameraLeft(l,scene);
+    }
+
+    @Override
+    public void moveCameraLeftImmediately(double l,int scene) {
+        canvas.moveCameraLeftImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraUp(double l,int scene) {
+        canvas.moveCameraUp(l,scene);
+    }
+
+    @Override
+    public void moveCameraUpImmediately(double l,int scene) {
+        canvas.moveCameraUpImmediately(l,scene);
+    }
+
+    @Override
+    public void moveCameraDown(double l,int scene) {
+        canvas.moveCameraDown(l,scene);
+    }
+
+    @Override
+    public void moveCameraDownImmediately(double l,int scene) {
+        canvas.moveCameraDownImmediately(l,scene);
+    }
+
     @Override
     public Vector3d getCameraLoc() {
         return canvas.getCameraLoc();
