@@ -211,7 +211,7 @@ class PickingBehavior extends Behavior {
     // 座標計算とピッキング
     Point3d canvasToVirtualCS(int x,int y,double dis) {
         Point3d point = canvasToPhysicalCS(x,y,dis);
-        physicalCSToVirtualCS(point);
+        point = physicalCSToVirtualCS(point);
         return point;
     }
     Point3d canvasToVirtualCS(int x,int y) {
@@ -300,28 +300,32 @@ class PickingBehavior extends Behavior {
     }
 
     Point3d physicalCSToVirtualCS(Point3d p) {
+        Point3d pp = new Point3d(p);
         canvas.getTransformGroupForViewPlatform().getTransform(vpt);
-        vpt.transform(p);
-        return p;
+        vpt.transform(pp);
+        return pp;
     }
     /* Vector3dで計算させると期待どうりにならないことが判明
     Vector3d physicalCSToVirtualCS(Vector3d v) {
+        Vector3d vv = new Vector3d(v);
         vptg.getTransform(vpt);
-        vpt.transform(v);
-        return v;
+        vpt.transform(vv);
+        return vv;
     }*/
     Point3d virtualCSToPhysicalCS(Point3d p) {
+        Point3d pp = new Point3d(p);
         canvas.getTransformGroupForViewPlatform().getTransform(vpt);
         vpt.invert();
-        vpt.transform(p);
-        return p;
+        vpt.transform(pp);
+        return pp;
     }
     /* Vector3dで計算させると期待どうりにならないことが判明
     Vector3d virtualCSToPhysicalCS(Vector3d v) {
+        Vector3d vv = new Vector3d(v);
         vptg.getTransform(vpt);
         vpt.invert();
-        vpt.transform(v);
-        return v;
+        vpt.transform(vv);
+        return vv;
     }*/
 
     A3Object pickA3(int x,int y) {
