@@ -355,6 +355,80 @@ class Scene implements Component2DContainerInterface {
         cameraNextV.add(loc);
         cameraNowV.set(cameraNextV);
     }
+
+    public void moveCameraForward(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,0,1));
+        v.scale(-l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraForwardImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,0,1));
+        v.scale(-l);
+        addCameraLocImmediately(v);
+    }
+
+    public void moveCameraBackward(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,0,1));
+        v.scale(l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraBackwardImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,0,1));
+        v.scale(l);
+        addCameraLocImmediately(v);
+    }
+
+    public void moveCameraRight(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(1,0,0));
+        v.scale(l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraRightImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(1,0,0));
+        v.scale(l);
+        addCameraLocImmediately(v);
+    }
+
+    public void moveCameraLeft(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(1,0,0));
+        v.scale(-l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraLeftImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(1,0,0));
+        v.scale(-l);
+        addCameraLocImmediately(v);
+    }
+
+    public void moveCameraUp(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,1,0));
+        v.scale(l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraUpImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,1,0));
+        v.scale(l);
+        addCameraLocImmediately(v);
+    }
+
+    public void moveCameraDown(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,1,0));
+        v.scale(-l);
+        addCameraLoc(v);
+    }
+
+    public void moveCameraDownImmediately(double l) {
+        Vector3d v = Util.trans(cameraNowQ,new Vector3d(0,1,0));
+        v.scale(-l);
+        addCameraLocImmediately(v);
+    }
+    
+
     /**
      * カメラの現在位置を返します。
      */
@@ -606,6 +680,10 @@ class Scene implements Component2DContainerInterface {
             setA3Controller0(new SimpleController(params));
         else if (naviMode == NaviMode.CHASE)
             setA3Controller0(new ChaseController(params));
+        else if (naviMode == NaviMode.FPS)
+            setA3Controller0(new FPSController(params));
+        else if (naviMode == NaviMode.FPS_FLY)
+            setA3Controller0(new FPSFlyController(params));
     }
 
     double naviSpeed = 1.0;
