@@ -63,8 +63,8 @@ import javax.vecmath.Point3d;
 import javax.vecmath.Point3f;
 import javax.vecmath.Vector3d;
 import javax.vecmath.Vector3f;
-import net.java.games.joal.AL;
-import net.java.games.joal.util.ALut;
+import com.jogamp.openal.AL;
+import com.jogamp.openal.util.ALut;
 
 /** This is the JOAL Sample object which encapsulates all the functionality
  *  and holds all the data associated with a Sample.
