@@ -1,6 +1,6 @@
 package jp.sourceforge.acerola3d.sound;
 
-import net.java.games.joal.*;
+import com.jogamp.openal.*;
 
 import javax.vecmath.*;
 import javax.sound.sampled.*;
@@ -45,6 +45,7 @@ public class ShortSound implements A3Sound {
     }
 
     void initBuffer() throws Exception {
+        if (soundSystem.al==null) return;
         int format[] = new int[1];
         ByteBuffer data[] = new ByteBuffer[1];
         int size[] = new int[1];
@@ -94,6 +95,7 @@ System.out.println("sum:"+sum);
         soundSystem.al.alBufferData(buffer[0],format[0],data[0],size[0],freq[0]); check(2);
     }
     void initSource() {
+        if (soundSystem.al==null) return;
         soundSystem.al.alGenSources(1,source,0); check(3);
         sourceInit=true;
 
@@ -147,11 +149,13 @@ System.out.println("sum:"+sum);
         return sourceInit;
     }
     public void start() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             initSource();
         soundSystem.al.alSourcePlay(source[0]); check(5);
     }
     public void segno() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         soundSystem.al.alSourcef(source[0],AL.AL_SEC_OFFSET,segnoTime);// check(6);
@@ -159,6 +163,7 @@ System.out.println("sum:"+sum);
         soundSystem.al.alSourcePlay(source[0]); check(7);
     }
     public void stop() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         soundSystem.al.alSourceStop(source[0]);
@@ -166,16 +171,19 @@ System.out.println("sum:"+sum);
         sourceInit=false;
     }
     public void pause() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         soundSystem.al.alSourcePause(source[0]);
     }
     public void rewind() {
+        if (soundSystem.al==null) return;
         if (!alIsSource())
             return;
         soundSystem.al.alSourceRewind(source[0]);
     }
     public void setLoc(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         if (type!=A3SoundType.BackgroundSound) {
             loc.set(x,y,z);
             if (alIsSource()) {
@@ -197,6 +205,7 @@ System.out.println("sum:"+sum);
         setQuat(q);
     }
     public void setQuat(Quat4d q) {
+        if (soundSystem.al==null) return;
         if (type!=A3SoundType.BackgroundSound) {
             quat.set(q);
             Vector3d v = Util.trans(q,new Vector3d(orgDir));
@@ -208,6 +217,7 @@ System.out.println("sum:"+sum);
     public void setVel() {
     }
     public void setGain(float g) {
+        if (soundSystem.al==null) return;
         gain = g;
         if (alIsSource())
             soundSystem.al.alSourcef(source[0],AL.AL_GAIN,g);
@@ -216,6 +226,7 @@ System.out.println("sum:"+sum);
         return gain;
     }
     public void setDirection(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         orgDir.set(x,y,z);
         Vector3d v = Util.trans(quat,new Vector3d(orgDir));
         dir.set(v);
@@ -226,6 +237,7 @@ System.out.println("sum:"+sum);
         setDirection((float)d.x,(float)d.y,(float)d.z);
     }
     public void setOffset(float x,float y,float z) {
+        if (soundSystem.al==null) return;
         offset.set(x,y,z);
         if (alIsSource()) {
             Vector3d v = Util.trans(quat,new Vector3d(offset));
@@ -237,6 +249,7 @@ System.out.println("sum:"+sum);
         setOffset((float)o.x,(float)o.y,(float)o.z);
     }
     public void setLoop(boolean l) {
+        if (soundSystem.al==null) return;
         loop = l;
         if (alIsSource()) {
             if (loop) {
@@ -247,6 +260,7 @@ System.out.println("sum:"+sum);
         }
     }
     public void cleanUp() {
+        if (soundSystem.al==null) return;
         soundSystem.al.alSourceStop(source[0]);
         soundSystem.al.alDeleteSources(1,source,0);
         sourceInit=false;
@@ -256,6 +270,7 @@ System.out.println("sum:"+sum);
         }
     }
     public void setType(A3SoundType t) {
+        if (soundSystem.al==null) return;
         type = t;
         if (!alIsSource())
             return;
@@ -300,6 +315,7 @@ System.out.println("sum:"+sum);
         return ret;
     }
     void check(int i) {
+        if (soundSystem.al==null) return;
         int e = soundSystem.al.alGetError();
         if (e==AL.AL_NO_ERROR)
             return;
